@@ -7,12 +7,14 @@ from django.utils.functional import cached_property
 
 
 class DatabaseFeatures(PostgresDatabaseFeatures):
+    minimum_database_version = (21, 2)
+
     # Cloning databases doesn't speed up tests.
     # https://github.com/cockroachdb/django-cockroachdb/issues/206
     can_clone_databases = False
 
     # Not supported: https://github.com/cockroachdb/cockroach/issues/40476
-    has_select_for_update_skip_locked = property(operator.attrgetter('is_cockroachdb_22_2'))
+    has_select_for_update_skip_locked = False
 
     # Not supported: https://github.com/cockroachdb/cockroach/issues/31632
     can_defer_constraint_checks = False
@@ -28,8 +30,7 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
     create_test_procedure_without_params_sql = None
     create_test_procedure_with_int_param_sql = None
 
-    # Sequences on AutoField don't begin (or reset) to 1 like other databases
-    # due to use of DEFAULT unique_rowid().
+    # Not supported: https://github.com/cockroachdb/cockroach/issues/20956
     supports_sequence_reset = False
 
     # Forward references in fixtures won't work until cockroachdb can
@@ -55,7 +56,7 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
             'BigAutoField': 'BigIntegerField',
             'IntegerField': 'BigIntegerField',
             'PositiveIntegerField': 'BigIntegerField',
-            'SmallAutoField': 'BigIntegerField',
+            'SmallAutoField': 'SmallIntegerField',
         }
 
     supports_order_by_nulls_modifier = property(operator.attrgetter('is_cockroachdb_22_1'))
@@ -74,25 +75,10 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
         'swedish_ci': 'sv-x-icu',
     }
 
-    # Not supported: https://github.com/cockroachdb/cockroach/issues/9682
-    supports_expression_indexes = property(operator.attrgetter('is_cockroachdb_21_2'))
-
-    @cached_property
-    def is_cockroachdb_21_1(self):
-        return self.connection.cockroachdb_version >= (21, 1)
-
-    @cached_property
-    def is_cockroachdb_21_2(self):
-        return self.connection.cockroachdb_version >= (21, 2)
-
     @cached_property
     def is_cockroachdb_22_1(self):
         return self.connection.cockroachdb_version >= (22, 1)
 
-    @cached_property
-    def is_cockroachdb_22_2(self):
-        return self.connection.cockroachdb_version >= (22, 2)
-
     @cached_property
     def django_test_expected_failures(self):
         expected_failures = super().django_test_expected_failures
@@ -148,13 +134,16 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
             # https://go.crdb.dev/issue/47636
             'migrations.test_executor.ExecutorTests.test_alter_id_type_with_fk',
             'migrations.test_operations.OperationTests.test_alter_field_pk_fk',
+            'migrations.test_operations.OperationTests.test_alter_field_pk_fk_db_collation',
             'migrations.test_operations.OperationTests.test_alter_field_reloads_state_on_fk_target_changes',
             'migrations.test_operations.OperationTests.test_alter_field_reloads_state_fk_with_to_field_related_name_target_type_change',  # noqa
             'migrations.test_operations.OperationTests.test_alter_field_reloads_state_on_fk_with_to_field_target_changes',  # noqa
             'migrations.test_operations.OperationTests.test_alter_field_reloads_state_on_fk_with_to_field_target_type_change',  # noqa
             'migrations.test_operations.OperationTests.test_rename_field_reloads_state_on_fk_target_changes',
             'schema.tests.SchemaTests.test_alter_auto_field_to_char_field',
-            'schema.tests.SchemaTests.test_alter_autofield_pk_to_smallautofield_pk_sequence_owner',
+            'schema.tests.SchemaTests.test_alter_autofield_pk_to_smallautofield_pk',
+            'schema.tests.SchemaTests.test_alter_primary_key_db_collation',
+            'schema.tests.SchemaTests.test_alter_primary_key_the_same_name',
             'schema.tests.SchemaTests.test_char_field_pk_to_auto_field',
             'schema.tests.SchemaTests.test_char_field_with_db_index_to_fk',
             'schema.tests.SchemaTests.test_text_field_with_db_index_to_fk',
@@ -166,6 +155,7 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
             # SmallAutoField doesn't work:
             # https://github.com/cockroachdb/cockroach-django/issues/84
             'bulk_create.tests.BulkCreateTests.test_bulk_insert_nullable_fields',
+            'many_to_one.tests.ManyToOneTests.test_add_remove_set_by_pk_raises',
             'many_to_one.tests.ManyToOneTests.test_fk_to_smallautofield',
             'migrations.test_operations.OperationTests.test_smallfield_autofield_foreignfield_growth',
             'migrations.test_operations.OperationTests.test_smallfield_bigautofield_foreignfield_growth',
@@ -207,12 +197,9 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
                 # Passing a naive datetime to cursor.execute() doesn't work in
                 # older versions of CockroachDB.
                 'timezones.tests.LegacyDatabaseTests.test_cursor_execute_accepts_naive_datetime',
-            })
-        if not self.connection.features.is_cockroachdb_21_2:
-            expected_failures.update({
-                # interval division with float rounds differently from Python.
-                # https://github.com/cockroachdb/cockroach/issues/66118
-                'expressions.tests.FTimeDeltaTests.test_durationfield_multiply_divide',
+                # unknown signature: date_trunc(string, interval):
+                # https://github.com/cockroachdb/cockroach/issues/76960
+                'db_functions.datetime.test_extract_trunc.DateFunctionTests.test_extract_second_func_no_fractional',
             })
         return expected_failures
 
